coherence.upnp.devices.media_renderer (module) — Cohen3 0.8.0 documentation

# coherence.upnp.devices.media_renderer (module)

class `HttpRoot`(server)

  Bases: `coherence.upnp.devices.basics.DeviceHttpRoot`

  `logCategory` = 'mediarenderer'

class `MediaRenderer`(coherence, backend, **kwargs)

  Bases: `coherence.log.LogAble`, `coherence.upnp.devices.basics.BasicDeviceMixin`

  `logCategory` = 'mediarenderer'
  `device_type` = 'MediaRenderer'
  `fire`(backend, **kwargs)
  `init_complete`(backend)